@@ -1,4 +1,5 @@
-# $Id: snmp.pl,v 1.2 2008/01/25 13:46:04 dk Exp $
+#!/usr/bin/perl
+# $Id: snmp.pl,v 1.4 2012/01/14 10:33:30 dk Exp $
 use strict;
 use SNMP;
 use IO::Lambda::SNMP qw(:all);
@@ -14,9 +15,16 @@ this lambda {
 	context $sess, new SNMP::Varbind;
 	snmpgetnext {
 		my $vb = shift;
-		print @{$vb->[0]}, "\n" ; 
+
+		# check success
+		return unless $vb;
+		return if $sess-> {ErrorNum};
+		return if $vb->[0]->[2] eq 'ENDOFMIBVIEW';
+
+		# print and resubmit
+		print "@{$vb->[0]}\n" ; 
 		context $sess, $vb;
-		again unless $sess-> {ErrorNum};
+		again;
 	};
 };
 this-> wait;
