@@ -9,7 +9,7 @@ $RETRIES = 4;   # times
 
 use strict;
 use Socket;
-use Net::DNS::Resolver;
+use Net::DNS::Resolver 1.05;
 use IO::Lambda qw(:all);
 
 # given the options, returns new dns lambda
@@ -51,19 +51,7 @@ lambda {
 	my $bg_obj = $obj-> bgsend( @ctx);
 	return "send error: " . $obj-> errorstring unless $bg_obj;
 
-	my $sock;
-	if ( $Net::DNS::VERSION > 1.02 ) {
-		# this is a IO::Select object
-		my @handles = $bg_obj->handles;
-		if ( 1 != @handles ) {
-			warn "There's something wrong with Net::DNS version $Net::DNS::VERSION, please notify the author\n";
-			return "panic: Net::DNS returned not 1 socket\n";
-		}
-		$sock = $handles[0]->[0];
-	} else {
-		$sock = $bg_obj;
-	}
-
+	my $sock = $bg_obj;
 	context $sock, $timeout;
 readable {
 	unless ( shift) {
@@ -76,7 +64,7 @@ readable {
 		$! = $err;
 		return "socket error: $!";
 	}
-	return again unless $obj-> bgisready($bg_obj);
+	return again if $obj-> bgbusy($bg_obj);
 
 	my $packet = $obj-> bgread( $bg_obj);
 	undef $sock;
